==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationStatusBuilder extends PolicyAutomationStatusFluentImpl<PolicyAutomationStatusBuilder> implements VisitableBuilder<PolicyAutomationStatus,PolicyAutomationStatusBuilder>{
  public PolicyAutomationStatusBuilder() {
    this(false);
  }
  public PolicyAutomationStatusBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationStatus(), validationEnabled);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationStatus(), validationEnabled);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,PolicyAutomationStatus instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,PolicyAutomationStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatus instance) {
    this(instance,false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationStatus build() {
    PolicyAutomationStatus buildable = new PolicyAutomationStatus();
    return buildable;
  }
  
}

==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationStatusBuilder extends PolicyAutomationStatusFluent<PolicyAutomationStatusBuilder> implements VisitableBuilder<PolicyAutomationStatus,PolicyAutomationStatusBuilder>{
  public PolicyAutomationStatusBuilder() {
    this(false);
  }
  public PolicyAutomationStatusBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationStatus(), validationEnabled);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationStatus(), validationEnabled);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,PolicyAutomationStatus instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatusFluent<?> fluent,PolicyAutomationStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PolicyAutomationStatus());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatus instance) {
    this(instance,false);
  }
  public PolicyAutomationStatusBuilder(PolicyAutomationStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PolicyAutomationStatus());

    if (instance != null) {
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationStatus build() {
    PolicyAutomationStatus buildable = new PolicyAutomationStatus();
    return buildable;
  }
  
}
